@@ -15,6 +15,7 @@ use Class::C3;
 use base qw(
     WebGUI::AssetAspect::Subscribable
     WebGUI::AssetAspect::Comments 
+    WebGUI::AssetAspect::AutoSynopsis
     WebGUI::Asset
 );
 use Tie::IxHash;
@@ -164,7 +165,7 @@ sub getAutoCommitWorkflowId {
 
         # delete spam
         my $spamStopWords = $self->session->config->get('spamStopWords');
-        if (ref $spamStopWords eq 'ARRAY') {
+        if (ref $spamStopWords eq 'ARRAY' && @{ $spamStopWords }) {
             my $spamRegex = join('|',@{$spamStopWords});
             $spamRegex =~ s/\s/\\ /g;
             if ($self->get('content') =~ m{$spamRegex}xmsi) {
@@ -265,13 +266,17 @@ Get the common template vars for this asset
 
 sub getTemplateVars {
     my ( $self ) = @_;
-    my $i18n        = WebGUI::International->new($self->session, "Asset_WikiPage");
-    my $wiki        = $self->getWiki;
-    my $owner       = WebGUI::User->new( $self->session, $self->get('ownerUserId') );
-    my $keywords    = WebGUI::Keyword->new($self->session)->getKeywordsForAsset({
+    my $session  = $self->session;
+    my $i18n     = WebGUI::International->new($session, "Asset_WikiPage");
+    my $wiki     = $self->getWiki;
+    my $owner    = WebGUI::User->new( $session, $self->get('ownerUserId') );
+    my $keyObj   = WebGUI::Keyword->new($session);
+
+    my $keywords    = $keyObj->getKeywordsForAsset({
         asset       => $self,
         asArrayRef  => 1,
     });
+
     my @keywordsLoop = ();
     foreach my $word (@{$keywords}) {
         push @keywordsLoop, {
@@ -416,6 +421,8 @@ sub processPropertiesFromFormPost {
         $properties->{isFeatured}  = $session->form->get("isFeatured");
     }
 
+    ($properties->{synopsis}) = $self->getSynopsisAndContent(undef, $self->get('content'));
+
 	$self->update($properties);
 
     # deal with attachments from the attachments form control
@@ -469,6 +476,7 @@ sub scrubContent {
         my $self = shift;
         my $content = shift || $self->get("content");
 
+        $content =~ s/\^-\;//g;
         my $scrubbedContent = WebGUI::HTML::filter($content, $self->getWiki->get("filterCode"));
 
         if ($self->getWiki->get("useContentFilter")) {
