@@ -872,9 +872,11 @@ sub www_addTicketsToBadge {
 		my $badge = WebGUI::Asset->new($session, $assetId, 'WebGUI::Asset::Sku::EMSBadge');
                 if ( defined $badge ) {
                     my @badgeGroups = split("\n",$badge->get('relatedBadgeGroups'));
-                    %badgeGroups = $db->buildHash( 
-                        "SELECT badgeGroupId, ticketsPerBadge FROM EMSBadgeGroup WHERE badgeGroupId IN (" . $db->quoteAndJoin(\@badgeGroups) . ")",
-                    );
+                    if (@badgeGroups) {
+                        %badgeGroups = $db->buildHash(
+                            "SELECT badgeGroupId, ticketsPerBadge FROM EMSBadgeGroup WHERE badgeGroupId IN (" . $db->quoteAndJoin(\@badgeGroups) . ")",
+                        );
+                    }
                 }
 	}
         	
@@ -1792,6 +1794,7 @@ sub www_getScheduleDataJSON {
                  and EMSTicket.location in (  } . 
 		         join( ',', (map { $db->quote($_) } (@ticketLocations))) .
 			 q{ )
+                 and asset.state='published'
                  and assetData.revisionDate = (
                            select max(revisionDate)
                              from assetData
@@ -1908,9 +1911,11 @@ className='WebGUI::Asset::Sku::EMSTicket' and state='published' and revisionDate
 		my $badge = WebGUI::Asset->new($session, $assetId, 'WebGUI::Asset::Sku::EMSBadge');
                 if ( defined $badge ) {
                     my @badgeGroups = split("\n",$badge->get('relatedBadgeGroups'));
-                    %badgeGroups = $db->buildHash( 
-                        "SELECT badgeGroupId, ticketsPerBadge FROM EMSBadgeGroup WHERE badgeGroupId IN (" . $db->quoteAndJoin(\@badgeGroups) . ")",
-                    );
+                    if (@badgeGroups) {
+                        %badgeGroups = $db->buildHash(
+                            "SELECT badgeGroupId, ticketsPerBadge FROM EMSBadgeGroup WHERE badgeGroupId IN (" . $db->quoteAndJoin(\@badgeGroups) . ")",
+                        );
+                    }
                 }
 	}
         	
