@@ -24,7 +24,7 @@ use HTML::Parser;
 use URI::Escape;
 use WebGUI::Form;
 use WebGUI::Search;
-use Clone qw/clone/;
+use Storable qw/dclone/;
 
 #-------------------------------------------------------------------
 
@@ -618,7 +618,7 @@ sub getKeywordVariables {
     my $variables = [];
 
     KEYWORD: foreach my $member (@{ $hierarchy }) {
-        my $varBlock             = clone $member;
+        my $varBlock             = dclone $member;
         $varBlock->{level}       = $level;
         $varBlock->{isTopLevel}  = $level == 0;
         $varBlock->{indent_loop} = [ map { { indent => $_ } } 1..$level ];
@@ -998,7 +998,7 @@ sub www_search {
 		$search->search({ keywords => $queryString,
 				  lineage => [$self->get('lineage')],
 				  classes => ['WebGUI::Asset::WikiPage'] });
-		my $rs = $search->getPaginatorResultSet($self->getUrl("func=search;query=".$queryString));
+		my $rs = $search->getPaginatorResultSet($self->getUrl("func=search;query=".$self->session->url->escape($queryString)));
 		$rs->appendTemplateVars($var);
 		my @results = ();
 		foreach my $row (@{$rs->getPageData}) {
