@@ -494,7 +494,7 @@ sub editUserForm {
 	);
 	$f->text(
 		-name => "authLDAP_connectDN",
-		-label => $i18n->get(4),
+		-label => $i18n->get('LDAP User DN'),
 		-value => $connectDN,
 	);
 	$self->session->style->setRawHeadTags($jscript);
@@ -600,7 +600,34 @@ sub getCreateAccountTemplateId {
     my $self = shift;
     my $ldapConnect = $self->getLDAPConnection;
     return "PBtmpl0000000000000005" unless $ldapConnect;
-	return ($self->getLDAPConnection->{ldapCreateAccountTemplate} || "PBtmpl0000000000000005");
+	return ($ldapConnect->{ldapCreateAccountTemplate} || "PBtmpl0000000000000005");
+}
+
+#-------------------------------------------------------------------
+
+=head2 getDeactivateAccountTemplateId ( )
+
+Get the default template ID for the deactivate account form.
+
+=cut
+
+sub getDeactivateAccountTemplateId {
+    my $self = shift;
+    my $ldapConnect = $self->getLDAPConnection;
+    return $self->SUPER::getDeactivateAccountTemplateId unless $ldapConnect;
+    return ($ldapConnect->{ldapDeactivateAccountTemplate} || $self->SUPER::getDeactivateAccountTemplateId);
+}
+
+#-------------------------------------------------------------------
+
+=head2 getDefaultLoginTemplateId ( )
+
+Get the default template ID for the login form.
+
+=cut
+
+sub getDefaultLoginTemplateId {
+    return "PBtmpl0000000000000006";
 }
 
 #-------------------------------------------------------------------
@@ -643,8 +670,8 @@ Get the template ID for the login form.
 sub getLoginTemplateId {
     my $self = shift;
     my $ldapConnect = $self->getLDAPConnection;
-    return "PBtmpl0000000000000006" unless $ldapConnect;
-    return ($self->getLDAPConnection->{ldapLoginTemplate} || "PBtmpl0000000000000006");
+    return $self->getDefaultLoginTemplateId unless $ldapConnect;
+    return ($self->getLDAPConnection->{ldapLoginTemplate} || $self->getDefaultLoginTemplateId);
 }
 
 #-------------------------------------------------------------------
