@@ -20,10 +20,11 @@ use strict;
 use Class::InsideOut qw(readonly private id register);
 use JSON;
 use Tie::IxHash;
-use Clone qw/clone/;
+use Storable qw/dclone/;
 use WebGUI::DateTime;
 use WebGUI::Exception;
 use WebGUI::Utility;
+use WebGUI::Pluggable;
 
 private objectData => my %objectData;
 readonly session => my %session;
@@ -578,11 +579,16 @@ sub get {
 
 	# return a specific property
 	if (defined $name) {
-		return clone $objectData{id $self}{$name};
+        if (ref $objectData{id $self}{$name}) {
+            return dclone $objectData{id $self}{$name};
+        }
+        else {
+            return $objectData{id $self}{$name};
+        }
 	}
 
 	# return a copy of all properties
-	return clone $objectData{id $self};
+	return dclone $objectData{id $self};
 }
 
 #-------------------------------------------------------------------
@@ -976,7 +982,7 @@ sub update {
 	}
 
 	# set last updated
-	$data->{lastUpdated} ||= WebGUI::DateTime->new($session, time())->toDatabase;
+	$dbData->{lastUpdated} = $data->{lastUpdated} ||= WebGUI::DateTime->new($session, time())->toDatabase;
 
 	# update memory
 	my $refId = id $self;
@@ -991,20 +997,28 @@ sub update {
 
 =head2 updateFromFormPost ( )
 
-Calls update() on any properties that are available from $session->form. Returns 1 on success.
+Calls update() on all properties that the object expects.
 
 =cut
 
 sub updateFromFormPost {
-	my $self = shift;
-	my $session = $self->session;
-	my $form = $session->form;
-	my %data;
-	my $properties = $self->crud_getProperties($session);
-	foreach my $property ($form->param) {
-		$data{$property} = $form->get($property, $properties->{$property}{fieldType}, $properties->{$property}{defaultValue});
-	}
-	return $self->update(\%data);
+    my $self = shift;
+    my $session = $self->session;
+    my $form    = $session->form;
+    my $data    = $self->get();
+    my $properties = $self->crud_getProperties($session);
+    PROPERTY: foreach my $property (keys %{ $properties }) {
+        my $fieldType = 'WebGUI::Form::'.ucfirst $properties->{$property}{fieldType};
+        my $control = eval { WebGUI::Pluggable::instanciate($fieldType, "new", [ $self->session, { name => $property, } ]) };
+        if ($@) {
+            $self->session->errorHandler->error($@);
+            next PROPERTY;
+        }
+        next PROPERTY if ! $control->isInRequest;
+        $data->{$property} =
+            $form->get($property, $properties->{$property}{fieldType}, $properties->{$property}{defaultValue});
+    }
+	return $self->update($data);
 }
 
 
