@@ -15,21 +15,25 @@ our $HELP = {
         title     => 'asset template asset var title',
         body      => '',
         variables => [
-            { name => 'title', },
+            { name => 'assetId',    },
+            { name => 'assetIdHex', },
+            { name => 'title',     },
             { name => 'menuTitle', },
-            { name => 'url', },
-            { name => 'isHidden', },
+            { name => 'url',       },
+            { name => 'isHidden',  },
             { name => 'newWindow', },
             { name => 'encryptPage', },
             { name => 'ownerUserId', },
             { name => 'groupIdView', },
             { name => 'groupIdEdit', },
-            { name => 'synopsis', },
+            { name => 'synopsis',      },
             { name => 'extraHeadTags', },
-            { name => 'isPackage', },
+            { name => 'isPackage',   },
             { name => 'isPrototype', },
-            { name => 'status', },
+            { name => 'status',    },
             { name => 'assetSize', },
+            { name => 'keywords',
+              description => 'keywords template var' },
         ],
         fields  => [],
         related => []
