@@ -29,6 +29,7 @@ our $HELP = {
                 { name => 'editIcon' },
               ],
             },
+            { name => 'topStory' },
             { name => 'topStoryDeleteIcon',
               description => 'deleteIcon', },
             { name => 'topStoryEditIcon',
@@ -46,7 +47,12 @@ our $HELP = {
             { name => 'rssUrl'               },
             { name => 'atomUrl'              },
         ],
-        related => []
+        related => [
+              {
+                  namespace => 'Asset_Story',
+                  tag       => 'view template',
+              }
+        ],
     },
 
     'storytopic asset template variables' => {
