@@ -418,6 +418,38 @@ sub www_ajaxCreateUser {
 
 #-------------------------------------------------------------------
 
+=head2 www_confirmUserEmail ( )
+
+Process links clicked from mails sent out by the WaitForUserConfmration
+workflow activity.
+
+=cut
+
+sub www_confirmUserEmail {
+    my $session    = shift;
+    my $f          = $session->form;
+    my $instanceId = $f->get('instanceId');
+    my $token      = $f->get('token');
+    my $actId      = $f->get('activityId');
+    my $activity   = WebGUI::Workflow::Activity->new($session, $actId)
+        or die;
+    my $instance   = WebGUI::Workflow::Instance->new($session, $instanceId)
+        or die;
+    if ($activity->confirm($instance, $token)) {
+        my $msg  = $activity->get('okMessage');
+        unless ($msg) {
+            my $i18n = WebGUI::International->new($session, 'WebGUI');
+            $msg = $i18n->get('ok');
+        }
+        return $session->style->userStyle($msg);
+    }
+    else {
+        return $session->privilege->noAccess;
+    }
+}
+
+#-------------------------------------------------------------------
+
 =head2 www_ajaxDeleteUser ( )
 
 Delete a user using a web service.
@@ -773,7 +805,7 @@ sub www_editUserSave {
 
 	return $session->privilege->adminOnly() unless ($isAdmin || $isSecondary) && $session->form->validToken;
 
-	# Check to see if 
+    # Check to see if
 	# 1) the userId associated with the posted username matches the posted userId (we're editing an account)
 	# or that the userId is new and the username selected is unique (creating new account)
 	# or that the username passed in isn't assigned a userId (changing a username)
@@ -784,11 +816,11 @@ sub www_editUserSave {
 	my $postedUsername = $session->form->process("username");
 	$postedUsername = WebGUI::HTML::filter($postedUsername, "all");
 
-	if (($existingUserId eq $postedUserId || ($postedUserId eq "new" && !$existingUserId) || $existingUserId eq '')
+    if (($existingUserId eq $postedUserId || ($postedUserId eq "new" && !$existingUserId) || $existingUserId eq '')
              && $postedUsername ne '') 
              {
-		# Create a user object with the id passed in.  If the Id is 'new', the new method will return a new user,
-		# otherwise return the existing users properties
+        # Create a user object with the id passed in.  If the Id is 'new', the new method will return a new user,
+        # otherwise return the existing users properties
 	   	my $u = WebGUI::User->new($session,$postedUserId);
 	   	$actualUserId = $u->userId;
 	   	
@@ -806,10 +838,58 @@ sub www_editUserSave {
         }
        		
         # Loop through all profile fields, and update them with new values.
-		foreach my $field (@{WebGUI::ProfileField->getFields($session)}) {
+        my $address          = {};
+        my $address_mappings = WebGUI::Shop::AddressBook->getProfileAddressMappings;
+        foreach my $field (@{WebGUI::ProfileField->getFields($session)}) {
 			next if $field->getId =~ /contentPositions/;
-			$u->profileField($field->getId,$field->formProcess($u));
+            my $field_value = $field->formProcess($u);
+			$u->profileField($field->getId,$field_value);
+
+            #set the shop address fields
+            my $address_key          = $address_mappings->{$field->getId};
+            $address->{$address_key} = $field_value if ($address_key);
 		}
+
+        #Update or create and update the shop address
+        if ( keys %$address ) {
+            $address->{'isProfile'        } = 1;
+
+            #Get the address book for the user (one is created if it does not exist)
+            my $addressBook     = WebGUI::Shop::AddressBook->newByUserId($session,$actualUserId);
+            my $profileAddress = eval { $addressBook->getProfileAddress() };
+
+            my $e;
+            if($e = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound')) {
+                #Get home address only mappings to avoid creating addresses with just firstName, lastName, email
+                my %home_address_map = %{$address_mappings};
+                foreach my $exclude ( qw{ firstName lastName email } ) {
+                    delete $home_address_map{$exclude};
+                }
+                #Add the profile address for the user if there are homeAddress fields
+                if( grep { $address->{$_} } values %home_address_map ) {
+                    $address->{label} = "Profile Address";
+                    my $new_address = $addressBook->addAddress($address);
+                    #Set this as the default address if one doesn't already exist
+                    my $defaultAddress = eval{ $addressBook->getDefaultAddress };
+                    if(WebGUI::Error->caught('WebGUI::Error::ObjectNotFound')) {
+                        $addressBook->update( {
+                            defaultAddressId => $new_address->getId
+                        } );
+                    }
+                }
+            }
+            elsif ($e = WebGUI::Error->caught) {
+                #Bad stuff happened - log an error but don't fail since this isn't a vital function
+                $session->log->error(
+                    q{Could not update Shop Profile Address for user }
+                        .$u->username.q{ : }.$e->error
+                );
+            }
+            else {
+                #Update the profile address for the user
+                $profileAddress->update($address);
+            }
+        }
 		
 		# Update group assignements
 		my @groups = $session->form->group("groupsToAdd");
