@@ -17,6 +17,7 @@ package WebGUI::Session::Id;
 
 use strict;
 use Digest::MD5;
+use Scalar::Util qw( weaken );
 use Time::HiRes qw( gettimeofday usleep );
 use MIME::Base64;
 
@@ -121,7 +122,9 @@ A reference to the current session.
 sub new {
 	my $class = shift;
 	my $session = shift;
-	bless {_session=>$session}, $class;
+	my $self = bless {_session=>$session}, $class;
+        weaken( $self->{_session} );
+        return $self;
 }
 
 #-------------------------------------------------------------------
@@ -142,7 +145,7 @@ sub session {
 
 =head2 toHex ( guid )
 
-Returns the hex value of a guid
+Returns the hex value of a guid.  For all GUIDs generated by the generate method, the return value will be 32 characters long.  For some manually created invalid GUIDs, it may be 33 characters long.
 
 =head3 guid
 
@@ -151,11 +154,13 @@ guid to convert to hex value.
 =cut
 
 sub toHex {
-	my $self = shift;
+    my $self = shift;
     my $id   = shift;
     $id =~ tr{_-}{+/};
-    my $bin_id = decode_base64("$id==");
-    my $hex_id = sprintf('%*v02x', '', $bin_id);
+    $id .= 'AA';
+    my $bin_id = decode_base64($id);
+    my $hex_id = unpack("H*", $bin_id);
+    $hex_id =~ s/0{3,4}$//;
     return $hex_id
 }
 
