@@ -883,8 +883,8 @@ Hierbij worden het label en de bijbehorende waarde door het | teken gescheiden.
     'message' => 'Hoe lang moeten oude revisies van een Asset bewaard blijven? Oude Asset revisies zijn niet zichtbaar meer voor gebruikers maar blijven bewaard om eventueel terug te kunnen zetten'
   },
   'purge revision prompt' => {
-    'lastUpdated' => '1146833136',
-    'message' => 'Weet u zeker dat u deze revisie wilt verwijderen? Dit kan <strong>niet</strong> ongedaan worden gemaakt. '
+    'lastUpdated' => '1370018628',
+    'message' => 'Weet u zeker dat u deze revisie wilt verwijderen? Dit kan NIET ongedaan worden gemaakt. '
   },
   'purge trash after' => {
     'lastUpdated' => '1146833150',
