@@ -253,6 +253,10 @@ our $I18N = {
     'lastUpdated' => '1248178498',
     'message' => 'Foto URL'
   },
+  'photoHeight' => {
+    'lastUpdated' => '1370018883',
+    'message' => 'De hoogte van de schermen die in het Story Archive is ingesteld voor dit bericht.'
+  },
   'photoWidth' => {
     'lastUpdated' => '1253797571',
     'message' => 'De breedte van foto\'s, ingesteld in het verhalenarchief van dit verhaal.'
