@@ -131,6 +131,14 @@ hebben.'
     'lastUpdated' => '1249029203',
     'message' => 'Het GUID van ht sjabloon dat de lijst met assets maakt die overeenkomen met een trefwoord tijdens het exporteren van het Verhalenarchief.'
   },
+  'photo height' => {
+    'lastUpdated' => '1370018658',
+    'message' => 'Hoogte foto'
+  },
+  'photo height help' => {
+    'lastUpdated' => '1370018810',
+    'message' => 'Schermen in de foto-carrousel moeten een vaste hoogte hebben, omdat ze anders in sommige browsers niet goed worden weergegeven. Zet deze waarde op 0 om deze functie uit te zetten.'
+  },
   'photo width' => {
     'lastUpdated' => '1248968603',
     'message' => 'Breedte foto'
@@ -139,6 +147,10 @@ hebben.'
     'lastUpdated' => '1248968739',
     'message' => 'Foto\'s die door de YUI Carousel getoond worden hebben dezelfde grootte nodig om goed te functioneren. Deze breedte wordt voor alle foto\'s gebruikt. Stel in op 0 om deze functie uit te zetten.'
   },
+  'photoHeight' => {
+    'lastUpdated' => '1370018828',
+    'message' => 'De hoogte die gebruikt mag worden om de foto\'s weer te geven.'
+  },
   'photoWidth' => {
     'lastUpdated' => '1248968667',
     'message' => 'De breedte die toegekent wordt aan alle foto\'s van verhalen in dit archief.'
