@@ -116,10 +116,13 @@ is displayed as part of a Layout Asset, the Layout Asset's <b>Style Template</b>
 	},
 
     'mobileStyleTemplateId label' => {
-        message => 'Mobile Style Template'
+        message => 'Mobile Style Template',
+		lastUpdated => 1268412950,
     },
+
     'mobileStyleTemplateId description' => {
         message => q|Select a style template from the list to enclose your asset if it is viewed on a mobile browser|,
+		lastUpdated => 1268412949,
     },
 
 };
