@@ -53,13 +53,17 @@ our $I18N = {
     'lastUpdated' => '1233560369',
     'message' => '[[METHOD]] wird durch die Namen der Standardansichten aller verfügbaren Plugins ersetzt (Der Vorgabewert ist "view").'
   },
+  'profile_user_id' => {
+    'lastUpdated' => '1344184481',
+    'message' => 'Die userId des Benutzers dessen Account betrachtet wird.'
+  },
   'root_url' => {
     'lastUpdated' => '1233559459',
     'message' => 'Der URL zur Hauptansicht des Kontos.'
   },
   'user_full_name' => {
-    'lastUpdated' => '1253566282',
-    'message' => 'Der vollständige Name des Benutzers.'
+    'lastUpdated' => '1344184446',
+    'message' => 'Der vollständige Name des Benutzers dessen Account betrachtet wird.'
   },
   'user_member_since' => {
     'lastUpdated' => '1233559552',
