@@ -382,12 +382,12 @@ our $I18N = {
     'message' => 'Eine Variable die wahr ist, falls auf diese Mitteilung bereits geantwortet wurde.'
   },
   'mark as read label' => {
-    'lastUpdated' => '1244362593',
-    'message' => 'Als "gelesen" markieren.'
+    'lastUpdated' => '1305396853',
+    'message' => 'Als \'gelesen\' markieren.'
   },
   'mark as unread label' => {
-    'lastUpdated' => '1244063634',
-    'message' => 'Als "ungelesen" markieren'
+    'lastUpdated' => '1305396879',
+    'message' => 'Als \'ungelesen\' markieren'
   },
   'member since' => {
     'lastUpdated' => '1233944766',
