@@ -221,6 +221,10 @@ our $I18N = {
     'lastUpdated' => '1179837791',
     'message' => 'Formular Element, das es Moderatoren erlaubt, die Anzeige eines einzelnen Threads zu ändern. Dies ist nur verfügbar f&uuml;r Threads.'
   },
+  'keywords.form' => {
+    'lastUpdated' => '1344184514',
+    'message' => 'Ein Texteingabefeld für Schlüsselworte'
+  },
   'lock.form' => {
     'lastUpdated' => '1179834692',
     'message' => 'Eine Ja/Nein Schaltfläche, um den Thread zu sperren. Falls gesperrt, können keine weiteren Post hinzugefügt bzw. bestehende Posts bearbeitet werden.'
