@@ -249,6 +249,10 @@ our $I18N = {
     'lastUpdated' => '1252334589',
     'message' => 'Photo-URL'
   },
+  'photoHeight' => {
+    'lastUpdated' => '1363943836',
+    'message' => 'Die Höhe von Bildern im Berichtsarchiv für diesen Bericht'
+  },
   'photoWidth' => {
     'lastUpdated' => '1253865063',
     'message' => 'Breite der Photos, im Berichtarchiv für diesen Bericht definiert.'
