@@ -129,6 +129,15 @@ our $I18N = {
     'lastUpdated' => '1252337748',
     'message' => 'GUID des Templates um die Assetliste anzuzeigen, auf die ein Schlüsselwort zutrifft wenn das Berichtsarchiv exportiert wird.'
   },
+  'photo height' => {
+    'lastUpdated' => '1363943879',
+    'message' => 'Bildhöhe'
+  },
+  'photo height help' => {
+    'lastUpdated' => '1363944012',
+    'message' => 'Die Höhe von Bildern im Carousel müssen für bestimmte Browser festgelegt werden.
+Wenn Sie darauf verzichten möchten, geben Sie \'0\' ein.'
+  },
   'photo width' => {
     'lastUpdated' => '1252337759',
     'message' => 'Photobreite'
@@ -137,6 +146,10 @@ our $I18N = {
     'lastUpdated' => '1252337953',
     'message' => 'Photos die vom YUI Carousel angezeigt werden müssen für eine korrekte Darstellung die selbe Größe haben. Auf diese Breite werden alle Photos skaliert. Um dieses Feature auszuschalten die Breite auf 0 setzen.'
   },
+  'photoHeight' => {
+    'lastUpdated' => '1363944040',
+    'message' => 'Die Höhe zum Anzeigen von Bildern.'
+  },
   'photoWidth' => {
     'lastUpdated' => '1252337842',
     'message' => 'Die Breite auf die alle Photos, die zu Berichten in diesem Berichtsarchiv hochgeladen werden, skaliert werden'
